Assorted spelling fixes

Francois Gouget fgouget at free.fr
Wed Aug 10 06:45:42 CDT 2005


Changelog:

  * dlls/kernel/tests/thread.c
    dlls/ntdll/cdrom.c
    dlls/wined3d/device.c
    dlls/wined3d/directx.c
    dlls/wined3d/drawprim.c
    dlls/wined3d/vertexdeclaration.c
    dlls/wininet/tests/wininet_test.h
    tools/winapi/winapi.pm

    Francois Gouget <fgouget at free.fr>
    Assorted spelling fixes

-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
                             $live{free} || die "";
-------------- next part --------------
Index: dlls/kernel/tests/thread.c
===================================================================
RCS file: /var/cvs/wine/dlls/kernel/tests/thread.c,v
retrieving revision 1.23
diff -u -p -r1.23 thread.c
--- dlls/kernel/tests/thread.c	30 Jul 2005 19:03:46 -0000	1.23
+++ dlls/kernel/tests/thread.c	30 Jul 2005 20:55:23 -0000
@@ -83,7 +83,7 @@ typedef struct {
 } t1Struct;
 
 /* WinME supports OpenThread but doesn't know about access restrictions so
-   we require them to be either completly ignored or always obeyed.
+   we require them to be either completely ignored or always obeyed.
 */
 INT obeying_ars = 0; /* -1 == no, 0 == dunno yet, 1 == yes */
 #define obey_ar(x) \
@@ -96,7 +96,7 @@ INT obeying_ars = 0; /* -1 == no, 0 == d
       ? ok(!(x), "access restrictions obeyed\n") \
       : ok( (x), "access restrictions not obeyed\n"))
 
-/* Basic test that simulatneous threads can access shared memory,
+/* Basic test that simultaneous threads can access shared memory,
    that the thread local storage routines work correctly, and that
    threads actually run concurrently
 */
@@ -119,7 +119,7 @@ static DWORD WINAPI threadFunc1(LPVOID p
    for(i=0;i<NUM_THREADS;i++) {
      while(tstruct->threadmem[i]==0) ;
    }
-/* Check that noone cahnged our tls memory */
+/* Check that noone changed our tls memory */
    ok((int)TlsGetValue(tlsIndex)-1==tstruct->threadnum,
       "TlsGetValue failed\n");
    return NUM_THREADS+tstruct->threadnum;
@@ -323,7 +323,7 @@ static VOID test_TerminateThread(void)
   thread = CreateThread(NULL,0,threadFunc4,
                         (LPVOID)event, 0,&threadId);
   ok(thread!=NULL,"Create Thread failed\n");
-/* Terminate thread has a race condition in Wine.  If the thread is terminated
+/* TerminateThread has a race condition in Wine.  If the thread is terminated
    before it starts, it leaves a process behind.  Therefore, we wait for the
    thread to signal that it has started.  There is no easy way to force the
    race to occur, so we don't try to find it.
Index: dlls/ntdll/cdrom.c
===================================================================
RCS file: /var/cvs/wine/dlls/ntdll/cdrom.c,v
retrieving revision 1.66
diff -u -p -r1.66 cdrom.c
--- dlls/ntdll/cdrom.c	8 Aug 2005 11:02:32 -0000	1.66
+++ dlls/ntdll/cdrom.c	8 Aug 2005 14:32:36 -0000
@@ -1929,7 +1929,7 @@ static NTSTATUS DVD_ReadStructure(int de
  *        GetInquiryData
  *        Implements the IOCTL_GET_INQUIRY_DATA ioctl.
  *        Returns Inquiry data for all devices on the specified scsi bus
- *        Returns STATUS_BUFFER_TOO_SMALL if the output buffer is to small, 
+ *        Returns STATUS_BUFFER_TOO_SMALL if the output buffer is too small, 
  *        STATUS_INVALID_DEVICE_REQUEST if the given handle isn't to a SCSI device,
  *        or STATUS_NOT_SUPPORTED if the OS driver is too old
  */
Index: dlls/wined3d/device.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/device.c,v
retrieving revision 1.64
diff -u -p -r1.64 device.c
--- dlls/wined3d/device.c	3 Aug 2005 19:49:05 -0000	1.64
+++ dlls/wined3d/device.c	3 Aug 2005 20:20:11 -0000
@@ -272,7 +272,7 @@ void WINAPI IWineD3DDeviceImpl_SetupText
     APPLY_STATE(WINED3DTSS_RESULTARG);
     APPLY_STATE(WINED3DTSS_CONSTANT);
 #endif
-    /* a quick sanity check incase someone forgot to update this function */
+    /* a quick sanity check in case someone forgot to update this function */
     if (WINED3D_HIGHEST_TEXTURE_STATE > WINED3DTSS_CONSTANT) {
         FIXME("(%p) : There are more texture states than expected, update device.c to match\n", This);
     }
@@ -349,7 +349,7 @@ ULONG WINAPI IWineD3DDeviceImpl_Release(
             if (nextSwapchain != NULL) {
                 nextSwapchain = nextSwapchain->next;
             } else {
-                WARN("Expected to find the implicite swapchain\n");
+                WARN("Expected to find the implicit swapchain\n");
             }
 
             /* release all the other swapchains */
@@ -366,11 +366,11 @@ ULONG WINAPI IWineD3DDeviceImpl_Release(
             }
 
             if (This->swapchains != NULL) {
-                /* Swapchain 0 is special because it's created in startup with a hanging parent, so we have to release it's parent now */
+                /* Swapchain 0 is special because it's created in startup with a hanging parent, so we have to release its parent now */
                 IWineD3DSwapChain_GetParent(This->swapchains->swapchain, &swapChainParent);
                 IUnknown_Release(swapChainParent);           /* once for the get parent */
                 if (IUnknown_Release(swapChainParent)  > 0) {  /* the second time for when it was created */
-                    FIXME("(%p) Something's still holding the implicite swapchain\n", This);
+                    FIXME("(%p) Something's still holding the implicit swapchain\n", This);
                 }
             }
 
Index: dlls/wined3d/drawprim.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/drawprim.c,v
retrieving revision 1.26
diff -u -p -r1.26 drawprim.c
--- dlls/wined3d/drawprim.c	3 Aug 2005 19:49:05 -0000	1.26
+++ dlls/wined3d/drawprim.c	3 Aug 2005 21:50:45 -0000
@@ -1627,7 +1627,13 @@ void inline drawPrimitiveUploadTextures(
                   /* Load up the texture now */
                 IWineD3DBaseTexture_PreLoad((IWineD3DBaseTexture *) This->stateBlock->textures[i]);
                 IWineD3DDevice_SetupTextureStates((IWineD3DDevice *)This, i, REAPPLY_ALPHAOP);
-                /* this is a stub function representing the state blocks being seperated here we are only updating the texture state changes, other objects and units get updated when they change (or need to be updated), e.g. states that relate to a context member line the texture unit are only updated when the context needs updating */
+                /* this is a stub function representing the state blocks
+                 * being separated here we are only updating the texture
+                 * state changes, other objects and units get updated when
+                 * they change (or need to be updated), e.g. states that
+                 * relate to a context member line the texture unit are
+                 * only updated when the context needs updating
+                 */
                 /* Tell the abse texture to sync it's states */
                 IWineD3DBaseTexture_ApplyStateChanges(This->stateBlock->textures[i], This->stateBlock->textureState[i], This->stateBlock->samplerState[i]);
 
@@ -1641,7 +1647,7 @@ void inline drawPrimitiveUploadTextures(
                 This->stateBlock->textureDimensions[i] = GL_TEXTURE_1D;
                 glBindTexture(GL_TEXTURE_1D, This->dummyTextureName[i]);
             }
-/** these ops apply to the texture unit, so they are preseved between texture changes, but for now brute force and reapply all
+/** these ops apply to the texture unit, so they are preserved between texture changes, but for now brute force and reapply all
         dx9_1pass_emboss_bump_mapping and dx9_2pass_emboss_bump_mapping are good texts to make sure the states are being applied when needed **/
             set_tex_op((IWineD3DDevice *)This, FALSE, i, This->stateBlock->textureState[i][WINED3DTSS_COLOROP],
                         This->stateBlock->textureState[i][WINED3DTSS_COLORARG1],
Index: dlls/wined3d/vertexdeclaration.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/vertexdeclaration.c,v
retrieving revision 1.11
diff -u -p -r1.11 vertexdeclaration.c
--- dlls/wined3d/vertexdeclaration.c	28 Jul 2005 10:15:35 -0000	1.11
+++ dlls/wined3d/vertexdeclaration.c	28 Jul 2005 14:40:05 -0000
@@ -440,7 +440,7 @@ static HRESULT WINAPI IWineD3DVertexDecl
         return D3D_OK;
     }
 
-    /* The increadables and teenage mutant ninja turtles require this in d3d9 for NumElements == 0,
+    /* The Incredibles and Teenage Mutant Ninja Turtles require this in d3d9 for NumElements == 0,
     TODO: this needs to be tested against windows */
     if(*pSizeOfData == 0) {
         TRACE("(%p) : Requested the vertex declaration without specefying the size of the return buffer\n", This);
@@ -467,7 +467,7 @@ HRESULT WINAPI IWineD3DVertexDeclaration
         return D3D_OK;
     }
 
-    /* The increadables and teenage mutant ninja turtles require this for NumElements == 0,
+    /* The Incredibles and Teenage Mutant Ninja Turtles require this for NumElements == 0,
     TODO: this needs to be tested against windows */
     if(*pNumElements == 0) {
         TRACE("(%p) : Requested the vertex declaration without specefying the size of the return buffer\n", This);
@@ -476,7 +476,7 @@ HRESULT WINAPI IWineD3DVertexDeclaration
         return D3D_OK;
     }
 
-    /* just incase there's a simila problem to  The increadables and teenage mutant ninja without pNumElements = 0 */
+    /* just in case there's a similar problem to The Incredibles and Teenage Mutant Ninja Turtles without pNumElements = 0 */
     if (*pNumElements < This->declaration9NumElements) {
         *pNumElements = This->declaration9NumElements;
         FIXME("(%p) : Returning D3DERR_MOREDATA numElements %ld expected %u\n", iface, *pNumElements, This->declaration9NumElements);
Index: dlls/wininet/tests/wininet_test.h
===================================================================
RCS file: /var/cvs/wine/dlls/wininet/tests/wininet_test.h,v
retrieving revision 1.1
diff -u -p -r1.1 wininet_test.h
--- dlls/wininet/tests/wininet_test.h	13 Aug 2004 23:19:37 -0000	1.1
+++ dlls/wininet/tests/wininet_test.h	22 Jul 2005 10:12:45 -0000
@@ -20,7 +20,7 @@
 
 /* The Windows headers don't define A/W types for any of the following
  * structures and pointers :-(
- * Because for these structures there's not alignment or packing difference
+ * Because for these structures there's no alignment or packing difference
  * between the A and W versions, we just define a set of macros so the
  * generated tests work anyway.
  */
Index: tools/winapi/winapi.pm
===================================================================
RCS file: /var/cvs/wine/tools/winapi/winapi.pm,v
retrieving revision 1.13
diff -u -p -r1.13 winapi.pm
--- tools/winapi/winapi.pm	26 Oct 2004 00:12:21 -0000	1.13
+++ tools/winapi/winapi.pm	9 Aug 2005 12:12:47 -0000
@@ -197,12 +197,12 @@ sub parse_api_file($$) {
 	    if(!$forbidden) {
 		if(defined($module)) {
 		    if($$allowed_modules_unlimited{$type}) {
-			$output->write("$file: type ($type) already specificed as an unlimited type\n");
+			$output->write("$file: type ($type) already specified as an unlimited type\n");
 		    } elsif(!$$allowed_modules{$type}{$module}) {
 			$$allowed_modules{$type}{$module} = 1;
 			$$allowed_modules_limited{$type} = 1;
 		    } else {
-			$output->write("$file: type ($type) already specificed\n");
+			$output->write("$file: type ($type) already specified\n");
 		    }
 		} else {
 		    $$allowed_modules_unlimited{$type} = 1;


More information about the wine-patches mailing list
Index: dlls/wined3d/directx.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/directx.c,v
retrieving revision 1.47
diff -u -p -r1.47 directx.c
--- dlls/wined3d/directx.c	3 Aug 2005 11:00:28 -0000	1.47
+++ dlls/wined3d/directx.c	3 Aug 2005 19:56:26 -0000
@@ -1645,7 +1645,7 @@ HRESULT  WINAPI  IWineD3DImpl_CreateDevi
         IWineD3DStateBlock_AddRef((IWineD3DStateBlock*)object->updateStateBlock);
         /* Setup surfaces for the backbuffer, frontbuffer and depthstencil buffer */
 
         /* Setup some defaults for creating the implicite swapchain */
         ENTER_GL();
         IWineD3DImpl_FillGLCaps(&This->gl_info, IWineD3DImpl_GetAdapterDisplay(iface, Adapter));
         LEAVE_GL();
@@ -1653,7 +1653,7 @@ HRESULT  WINAPI  IWineD3DImpl_CreateDevi
         /* Setup the implicit swapchain */
         TRACE("Creating implicit swapchain\n");
         if (D3D_OK != D3DCB_CreateAdditionalSwapChain((IUnknown *) object->parent, pPresentationParameters, (IWineD3DSwapChain **)&swapchain) || swapchain == NULL) {
-            WARN("Failed to create implicite swapchain\n");
+            WARN("Failed to create implicit swapchain\n");
             goto create_device_error;
         }
 
@@ -1645,7 +1645,7 @@ HRESULT  WINAPI  IWineD3DImpl_CreateDevi
         /* Setup surfaces for the backbuffer, frontbuffer and depthstencil buffer */
 
-        /* Setup some defaults for creating the implicite swapchain */
+        /* Setup some defaults for creating the implicit swapchain */
         ENTER_GL();
         IWineD3DImpl_FillGLCaps(&This->gl_info, IWineD3DImpl_GetAdapterDisplay(iface, Adapter));